using System;
using System.Data;
using System.Collections;
using System.Collections.Generic;
using System.Windows.Forms;
using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;
using System.ComponentModel;
using System.Drawing;
using System.Text;
using Syncfusion.Windows.Forms;
using System.Linq;
using System.Collections.Specialized;


namespace WindowsFormsApplication1
{
	public partial class ServerPanel : UserControl
	{
		//constants
		private const string SERVER_IP_STR = "ServerIp";
		private const string SERVER_NAME_STR = "ServerName";
		private const string HAS_BEEN_MODIFIED_STR = "HasBeenModified";
		private const string SELECT_ALL_STR = "SelectAll";

		private ServerController _ServerController;
		private DataTable listTable;
		private string _userName;
		
		public ServerPanel(ServerController controller, string UserName)
		{
			_ServerController = controller;
			_userName = UserName;
			InitializeComponent();
		}

		/// <summary>
		/// Updates the grid with all patients.
		/// </summary>
		public void UpdateGridWithList()
		{
			buttonExport.Enabled = true;
			buttonSave.Enabled = true;

			try
			{
				// put code to update grid here
				listTable = new DataTable();

				// Setup the data table to be used as the data source
				listTable.Columns.Add(SERVER_NAME_STR);
				listTable.Columns.Add(SERVER_IP_STR);
				listTable.Columns.Add(HAS_BEEN_MODIFIED_STR);
				listTable.Columns.Add(SELECT_ALL_STR);

				gridGroupingControl.Table.SelectedRecords.Clear();

				// Assign from list4
				List<NetworkConfigurationEntry> collection = new List<NetworkConfigurationEntry>();
				NetworkConfigurationEntry entry = null;

				// Create an arraylist of random MyObjects.
				int count = 5;
				Random r = new Random();
				for (int j = 0; j < count; j++)
				{
					entry = new NetworkConfigurationEntry("server" + r.Next(5), "ipserver" + r.Next(5), true, true);
					collection.Add(entry);
				}

				gridGroupingControl.DataSource = collection;
			}
			catch (Exception ex)
			{
				System.Console.WriteLine("Exception in ServerPanel.UpdateGridWithDevices: " + ex.Message);
				string msg = ex.Message;
			}
			finally
			{
			}
		}

		/// <summary>
		/// Refresh Display, called by controller
		/// </summary>
		public void RefreshDisplay()
		{
			buttonDelete.Enabled = false;
			UpdateGridWithList();
			buttonDelete.Enabled = true;
		}

		/// <summary>
		/// Raises the <see cref="E:System.Windows.Forms.UserControl.Load"></see> event.
		/// </summary>
		/// <param name="e">An <see cref="T:System.EventArgs"></see> that contains the event data.</param>
		protected override void OnLoad(EventArgs e)
		{
			base.OnLoad(e);

			buttonDelete.Enabled = false;
			UpdateGridWithList();
			buttonDelete.Enabled = true;
		}

				
		/// <summary>
		/// Event handler that will update the list from the database
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		public void HandleRefreshList(object sender, EventArgs e)
		{
			RefreshDisplay();
		}

		/// <summary>
		/// Event handler which sets the grid to the focus upon
		/// returning focus of the control.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		public void HandleControlFocus(object sender, EventArgs e)
		{
			gridGroupingControl.Select();
			gridGroupingControl.Focus();
		}

		/// <summary>
		/// Handles the Click event of the buttonExport control.
		/// </summary>
		/// <param name="sender">The source of the event.</param>
		/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
		private void buttonExport_Click(object sender, EventArgs e)
		{
		}

		private void SaveChanges()
		{
		}
			 
		/// <summary>
		/// Event handler will do validation on the records that require it
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		private void HandleCurrentRecordContextChange(object sender, CurrentRecordContextChangeEventArgs e)
		{
			if (e.Action == CurrentRecordAction.LeaveRecordComplete)
				gridGroupingControl.Table.EndEdit();

			// If they are leaving the cell, call end edit
			if (e.Action == CurrentRecordAction.EndEditCalled)
			{
				Record rec = e.Record as Record;
				if (rec != null)
				{
					object o = rec.GetValue("ServerIp");
					string rd1_str = o.ToString();
					if (!rd1_str.Equals("aa"))
					{
						e.Cancel = true;
						MessageBox.Show("Error: ServerIp value is not 'aa' ");						
                        int index = this.gridGroupingControl.Table.AddNewRecord.GetRowIndex();
                        this.gridGroupingControl.TableControl.CurrentCell.MoveTo(index, 2);
                        this.gridGroupingControl.TableControl.CurrentCell.Activate(index, 2);
                        this.gridGroupingControl.TableControl.CurrentCell.BeginEdit();
					}
				}
			}
		}
		 		
		#region buttons
		private void gridGroupingControl_TableControlCellClick_1(object sender, GridTableControlCellClickEventArgs e)
		{

		}

		private void buttonSave_Click(object sender, EventArgs e)
		{
			SaveChanges();
		}

		private void buttonDelete_Click(object sender, EventArgs e)
		{

		}

		/// <summary>
		/// Handles the Click event of the buttonRefresh control.
		/// </summary>
		/// <param name="sender">The source of the event.</param>
		/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
		public void buttonRefresh_Click(object sender, EventArgs e)
		{
			RefreshDisplay();
		}
		#endregion buttons     
	}
}
